searchData={"content_type":"text/markdown","items":[{"doc":"EmailAddress provides top-level parsing & formatting API to deal with RFC5322-formatted\ne-mail addresses and (in the future) lists of e-mail addresses.\n\nThis library is meant to be very forgiving and deal with invalid / malformed e-mail\naddresses in a fashion allowing for a recovery and avoiding common errors that happen\nwhen clients send malformed emails.","ref":"EmailAddress.html","title":"EmailAddress","type":"module"},{"doc":"Given `EmailAddress.Address` struct return RFC5322-formatted String containing\ne-mail address.\n\nThis function performs escaping and quoting special characters found in `display_name` if and only if\nrequired, leaving `display_name` unquoted in cases when it's not necessary.","ref":"EmailAddress.html#format/1","title":"EmailAddress.format/1","type":"function"},{"doc":"iex> EmailAddress.format(%EmailAddress.Address{addr_spec: \"jack.black@example.com\", display_name: \"\"})\n    \"jack.black@example.com\"\n\n    iex> EmailAddress.format(%EmailAddress.Address{addr_spec: \"jack.black@example.com\", display_name: \"Jack Black\"})\n    \"Jack Black  \"\n\n    iex> EmailAddress.format(%EmailAddress.Address{addr_spec: \"jack.black@example.com\", display_name: \"Jack Black's Email\"})\n    \"Jack Black's Email  \"\n\n    iex> EmailAddress.format(%EmailAddress.Address{addr_spec: \"jack.black@example.com\", display_name: \"Jack   Email\"})\n    \"\\\"Jack   Email\\\"  \"\n\n    iex> EmailAddress.format(%EmailAddress.Address{addr_spec: \"jack.black@example.com\", display_name: \"jack.black@example.com\"})\n    \"\\\"jack.black@example.com\\\"  \"\n\n    iex> EmailAddress.format(%EmailAddress.Address{addr_spec: \"jack.black@example.com\", display_name: \"Jack Black\\\"\"})\n    \"\\\"Jack Black\\\\\\\"\\\"  \"\n\n    iex> EmailAddress.format(%EmailAddress.Address{addr_spec: \"jack.black@example.com\", display_name: \"Black, Jack\"})\n    \"\\\"Black, Jack\\\"  \"","ref":"EmailAddress.html#format/1-examples","title":"Examples - EmailAddress.format/1","type":"function"},{"doc":"Given string containing single e-mail address, return `EmailAddress.Address` struct\ncontaining `addr_spec` and `display_name` fields or nil if address could not be\nparsed.","ref":"EmailAddress.html#parse/1","title":"EmailAddress.parse/1","type":"function"},{"doc":"iex> EmailAddress.parse(\"jack.black@example.com\")\n    %EmailAddress.Address{addr_spec: \"jack.black@example.com\", display_name: \"\"}\n\n    iex> EmailAddress.parse(\"Jack Black  \")\n    %EmailAddress.Address{addr_spec: \"jack.black@example.com\", display_name: \"Jack Black\"}\n\n    iex> EmailAddress.parse(\"\\\"Jack@Black\\\"  \")\n    %EmailAddress.Address{addr_spec: \"jack.black@example.com\", display_name: \"Jack@Black\"}\n\n    iex> EmailAddress.parse(\"Jack Black jack.black@example.com\")\n    %EmailAddress.Address{addr_spec: \"jack.black@example.com\", display_name: \"Jack Black\"}\n\n    iex> EmailAddress.parse(\"Jack\\n\\rBlack\\tjack.black@example.com\")\n    %EmailAddress.Address{addr_spec: \"jack.black@example.com\", display_name: \"Jack Black\"}\n\n    iex> EmailAddress.parse(\"\\\"Jack@Black\\\"   \")\n    %EmailAddress.Address{addr_spec: \"jack.black@example.com\", display_name: \"Jack@Black\"}\n\n    iex> EmailAddress.parse(\"\")\n    nil\n\n    iex> EmailAddress.parse(\"Not an email\")\n    nil\n\n    iex> EmailAddress.parse(\"http://example.com\")\n    nil\n\n    iex> EmailAddress.parse(\"notanemail\")\n    nil\n\n    iex> EmailAddress.parse(\" \")\n    nil\n\n    iex> EmailAddress.parse(\"Not an email  \")\n    nil\n\n    iex> EmailAddress.parse(\"Jack Black jack.black@example.com>\")\n    %EmailAddress.Address{addr_spec: \"jack.black@example.com\", display_name: \"Jack Black\"}\n\n    iex> EmailAddress.parse(\"Jack Black\\\" jack.black@example.com>\")\n    %EmailAddress.Address{addr_spec: \"jack.black@example.com\", display_name: \"Jack Black\\\"\"}\n\n    iex> EmailAddress.parse(\"Jack.black@example.com jack.black@example.com\")\n    %EmailAddress.Address{addr_spec: \"jack.black@example.com\", display_name: \"Jack.black@example.com\"}\n\n    iex> EmailAddress.parse(\"Jack.black@example.com jack.black@example.com;,:\")\n    %EmailAddress.Address{addr_spec: \"jack.black@example.com\", display_name: \"Jack.black@example.com\"}\n\n    iex> EmailAddress.parse(\"Hubert Łępicki  \")\n    %EmailAddress.Address{addr_spec: \"hubert.łępicki@hubertłępicki.com\", display_name: \"Hubert Łępicki\"}\n\n    iex> EmailAddress.parse(\"Hubert Łępicki  \")\n    %EmailAddress.Address{addr_spec: \"hubert.łępicki@hubertłępicki.com\", display_name: \"Hubert Łępicki\"}\n\n    iex> EmailAddress.parse(\"client@example.com (Client Client)\")\n    %EmailAddress.Address{addr_spec: \"client@example.com\", display_name: \"Client Client\"}\n\n    iex> EmailAddress.parse(\"\\\"Black, Jack\\\"  \")\n    %EmailAddress.Address{addr_spec: \"jack.black@example.com\", display_name: \"Black, Jack\"}\n\n    iex> EmailAddress.parse(\"\\\"Black, Jack\\\"  \")\n    %EmailAddress.Address{addr_spec: \"jack.black@127.0.0.1\", display_name: \"Black, Jack\"}\n\n    iex> EmailAddress.parse(\"\\\"=?UTF-8?Q?Tesorer=C3=ADa?=\\\"  \")\n    %EmailAddress.Address{addr_spec: \"user@u-oerre.md\", display_name: \"=?UTF-8?Q?Tesorer=C3=ADa?=\"}","ref":"EmailAddress.html#parse/1-examples","title":"Examples - EmailAddress.parse/1","type":"function"},{"doc":"","ref":"EmailAddress.Address.html","title":"EmailAddress.Address","type":"module"}]}